"use strict";
const React = require("react");
const Classes = require("classnames");
const react_motion_ui_pack_1 = require("react-motion-ui-pack");
class PivotTabs extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            slide_in_from: undefined,
        };
        /**
         * A flag which tells the render method whether this component has mounted yet, without setting off another render when the value changes.
         */
        this.hasMounted = false;
    }
    componentDidMount() {
        this.hasMounted = true;
    }
    componentWillReceiveProps(nextProps) {
        const lastIndex = this.props.tabs.findIndex(tab => !!tab.selected);
        const newIndex = nextProps.tabs.findIndex(tab => !!tab.selected);
        //If last tab comes after new tab, slide in from right. Else, default to slide in from left.
        this.setState({
            slide_in_from: lastIndex < newIndex ? "Right" : "Left"
        });
    }
    handleTabClick(e, tab) {
        e.preventDefault();
        if (tab.selected) {
            return;
        }
        this.props.onChange(tab);
    }
    render() {
        const selected = this.props.tabs.find(t => t.selected);
        const tabs = this.props.tabs.map(tab => React.createElement("div", { key: `pivot-tab-${tab.name}`, className: Classes("pivot-tab", { active: !!tab.selected }) },
            React.createElement("button", { onClick: e => this.handleTabClick(e, tab) }, tab.name)));
        const slideInLeft = this.state.slide_in_from === "Left";
        const appear = {
            opacity: 0,
            translateX: this.hasMounted ? (slideInLeft ? -250 : 250) : 0,
            translateY: this.hasMounted ? 0 : 50,
        };
        return (React.createElement("div", { className: "pivot-tabs" },
            React.createElement(Header, { title: this.props.title, actions: this.props.actions }),
            React.createElement("div", { className: "pivot-tabs-container" }, tabs),
            React.createElement("hr", { className: "pivot-spacer" }),
            React.createElement(react_motion_ui_pack_1.default, { key: selected.name, appear: appear, component: `div`, runOnMount: true, enter: { opacity: 1, translateX: 0, translateY: 0 } },
                React.createElement("div", { key: `pivot-content`, className: "pivot-content" }, this.props.children))));
    }
}
exports.PivotTabs = PivotTabs;
/**
 * A Pivot component without the pivoting tabs. Use it to keep a clear theme across your apps, even on pages that don't use the Pivot.
 */
function Header(props) {
    return (React.createElement("div", { className: "pivot-tabs" },
        React.createElement("div", { className: "pivot-header" },
            React.createElement("h3", { className: "pivot-header-title" }, props.title),
            React.createElement("div", { className: "pivot-header-actions" }, props.actions)),
        React.createElement("hr", { className: "pivot-spacer" })));
}
exports.Header = Header;
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = PivotTabs;
